@@ -21,7 +21,13 @@ private:
     Ui::Items *ui;
 
 private slots:
+    void on_qsearch_clicked();
+    void on_search_textChanged(QString );
     void on_listWidget_itemClicked(QListWidgetItem* item);
+
+protected:
+    virtual void keyReleaseEvent(QKeyEvent* k);
+
 };
 
 #endif // ITEMS_H
