@@ -40,6 +40,16 @@ void Settings::LoadAll()
     else
         ui->checkBox->setChecked(true);
 
+    if ( settings.value("Autorotation","NO") == "NO" )
+        ui->checkBox_2->setChecked(false);
+    else
+        ui->checkBox_2->setChecked(true);
+
+    if ( settings.value("Vertical","NO") == "NO" )
+        ui->checkBox_3->setChecked(false);
+    else
+        ui->checkBox_3->setChecked(true);
+
     if ( (programas.count() > 0) && (programas.at(0) != "") )
     {
         GetProgram(programas.at(0));
@@ -333,3 +343,23 @@ void Settings::on_pushButton_11_clicked()
     Home* hw = new Home(this, "Backimage", "/home/user/MyDocs");
     hw->exec();
 }
+
+void Settings::on_checkBox_2_stateChanged(int )
+{
+    QSettings settings("cepiperez","homescreen-dockbar");
+    if ( ui->checkBox_2->isChecked() )
+        settings.setValue("Autorotation","YES");
+    else
+        settings.setValue("Autorotation","NO");
+    settings.sync();
+}
+
+void Settings::on_checkBox_3_stateChanged(int )
+{
+    QSettings settings("cepiperez","homescreen-dockbar");
+    if ( ui->checkBox_3->isChecked() )
+        settings.setValue("Vertical","YES");
+    else
+        settings.setValue("Vertical","NO");
+    settings.sync();
+}
